#!/bin/bash

## Данный файл является bash-скриптом для двухэтапной компиляции автотестов.
## Функция main собирается в объектный файл незаивисимо от основного проекта.
## Затем собирается сам проект, и main-функция подключается (линкуется) к нему.
## Такой подход позволяет ускорить сборку, так как тестовая библиотека будет
## компилироваться только один раз.

## Пример содержит следующие директории:
## Include – библиотека тестов Catch2 (https://github.com/catchorg/Catch2)
## Sources – исходные коды программы для тестирования
## Tests – исходные коды тестов

CXX='g++'
CXFLAGS='-std=c++11 -I./Include -I./Sources'

mainName=tests-main
mainLink=./${mainName}.o
testOut=./tests.out
testFiles="./Tests/tests-add.cc ./Sources/fileForTest.cc"

rm -f ${testOut}

if ! [ -f ${mainLink} ]; then
    echo "Compiling main..."
    ${CXX} ${CXFLAGS} -o ${mainLink} ./Tests/${mainName}.cc -c
fi

echo "Compiling tests..."
${CXX} ${CXFLAGS} -o ${testOut} ${mainLink} ${testFiles} && ${testOut} -s